@@ -5,5 +5,6 @@ from .theme_xkcd import theme_xkcd
 from .theme_matplotlib import theme_matplotlib
 from .theme_seaborn import theme_seaborn
 
-__ALL__ = ["theme_bw","theme_gray","theme_xkcd","theme_matplotlib",
+__all__ = ["theme_bw","theme_gray","theme_xkcd","theme_matplotlib",
            "theme_seaborn"]
+__all__ = [str(u) for u in __all__]
